#[repr(u8)]pub enum Method {
OpretFirst = 0,
TapretFirst = 1,
}Expand description
Method of DBC construction.
Method defines a set of parameters used by a single-use seal, such as:
- selection of bitcoin input;
- commitment algorithm;
- used hash functions.
Variants
OpretFirst = 0
OP_RETURN commitment present in the first OP_RETURN-containing transaction output, made with tagged SHA256 hash function.
TapretFirst = 1
Taproot-based OP_RETURN commitment present in the first Taproot transaction output, made with tagged SHA256 hash function.