Crate dbc

Deterministic bitcoin commitments library.

Deterministic bitcoin commitments are part of the client-side-validation. They allow to embed commitment to extra-transaction data into a bitcoin transaction in a provable way, such that it can always be proven that a given transaction contains one and only one commitment of a specific type for a given commitment protocol.

Modules

  • Homomorphic key tweaking-based deterministic commitment scheme.
  • ScriptPubkey-based OP_RETURN commitments.
  • Signature tweaking-based deterministic commitment scheme.
  • Taproot OP_RETURN-based deterministic bitcoin commitment scheme (“tapret”).

Structs

  • wrong deterministic bitcoin commitment closing method id ‘{0}’.

Enums

  • Method of DBC construction.

Constants

  • Name of the strict type library generated from the data types in this crate.

Traits

  • Deterministic bitcoin commitment proof types.